@@ -107,11 +107,12 @@ class VimondClient:
     def find_assets_by_metadata(self, metadata_key, metadata_value):
         return self._admin_request('GET', f'/api/metadata/lookup/assets/{metadata_key}.json?value={metadata_value}')
 
-    def find_assets_by_query(self, category_id, query):
+    def find_assets_by_query(self, category_id, query, size=25):
         """
         Finds assets from the specified category using an arbitrary SOLR query string
         :param category_id: the category to search in. "root" can also be used instead of a numeric ID.
         :param query: the raw query, e.g. "assetMeta_foo_text:bar AND updateTime:[NOW-7DAYS TO NOW]"
+        :param size: how many results to include. Defaults to 25 (Vimond's default value).
         :return:
         """
-        return self._admin_request('GET', f'/api/web/search/categories/{category_id}/assets.json?query={query}')
+        return self._admin_request('GET', f'/api/web/search/categories/{category_id}/assets.json?query={query}&size={size}')
