@@ -50,6 +50,8 @@ class UtilsTest(unittest.TestCase):
                     'foo': [{'value': True, 'lang': '*'}],
                     'bar': [{'value': 'very bar', 'lang': '*'}],
                     'baz': [{'value': 42, 'lang': '*'}],
+                    # Metadata entries can inexplicably exist without values
+                    'hurr': [{'lang': '*'}]
                 },
                 'empty': True
             }
@@ -58,6 +60,7 @@ class UtilsTest(unittest.TestCase):
         self.assertTrue(utils.get_metadata_value('foo', asset))
         self.assertEqual('very bar', utils.get_metadata_value('bar', asset))
         self.assertEqual(42, utils.get_metadata_value('baz', asset))
+        self.assertEqual(None, utils.get_metadata_value('hurr', asset))
         self.assertEqual(None, utils.get_metadata_value('ei ole', asset))
 
     def test_parse_category_metadata(self):
@@ -121,6 +124,45 @@ class UtilsTest(unittest.TestCase):
 
         self.assertEqual('dXNlcm5hbWU6cGFzc3dvcmQ=', token)
 
+    def test_create_update_asset_payload_skeleton(self):
+        # Check that "id" is required, Vimond gives misleading errors if it's missing
+        with self.assertRaises(ValueError):
+            utils.create_update_asset_payload({})
+
+        # Test with missing values
+        self.assertEqual({
+            'id': 123,
+            'live': False,
+            'archive': False,
+        }, utils.create_update_asset_payload({
+            'id': 123,
+        }))
+
+        # Test with values
+        self.assertEqual({
+            'id': 456,
+            'live': True,
+            'archive': True,
+        }, utils.create_update_asset_payload({
+            'id': 456,
+            'live': True,
+            'archive': True,
+        }))
+
+        # Test with payload
+        self.assertEqual({
+            'id': 789,
+            'live': False,
+            'archive': True,
+            'categoryId': 123456,
+        }, utils.create_update_asset_payload({
+            'id': 789,
+            'live': False,
+            'archive': True,
+        }, {
+            'categoryId': 123456
+        }))
+
 
 if __name__ == '__main__':
     unittest.main()
